<?php

/**
 * @file
 * Archibald module API documentation.
 */

/**
 * @defgroup archibald_queue_api Archibald Queue API
 * @{
 * Archibald builds upon the @link queue Drupal Queue @endlink to queue items
 * for later execution. It allows logic to be processed later. For example,
 * re-publishing a node, which failed because of a network failure, is a typical
 * use-case within Archibald.
 *
 * Items are tagged with a specific group name. This name must respect a certain
 * logic. For example, queues for nodes are marked "node:{nid}:{action}". This
 * allows queues to be deleted by group. For example:
 * @code
 * archibald_clear_queue("node:23:publish");
 * @endcode
 * It is also possible to pass wildcards, like so:
 * @code
 * archibald_clear_queue("node:23:*");
 * @endcode
 * This tagging of queued items is especially important when queued items become
 * obsolete. For example, a queued re-publishing becomes obsolete when the node
 * is deleted. Upon deletion, the entire queue related to the deleted node is
 * cleared, but other pending items are remained intact.
 *
 * Queued items register a callback, which can live inside a different file, as
 * long as this file is relative to the archibald module directory, and is an
 * .inc file (see module_load_include()).
 *
 * @see queue
 * @}
 */

/**
 * @defgroup archibald_api Archibald
 * @{
 * Archibald allows Drupal sites to connect to the national catalog of the
 * Swiss Digital School Library. Communication with the national catalog happens
 * through a REST API. The module relies on the dsb Client PHP library for
 * communicating with this REST API. This library can be found here:
 * https://github.com/educach/dsb-client
 *
 * In order to use this module, users need to register with educa.ch to become
 * a content partner. Content partner receive a username (usually an email),
 * a private RSA key and a passphrase. This information can then be used by the
 * dsb Client library to communicate with the REST API.
 *
 * @see https://github.com/educach/dsb-client
 * @see https://dsb-api.educa.ch/latest/doc
 * @}
 */

/**
 * @addtogroup hooks
 * @{
 */

/**
 * Implements hook_archibald_language_fallback_list_alter().
 *
 * Some LOM-CH data fields are multilingual. By default, the current session
 * language will be searched for first, followed by:
 * - de
 * - fr
 * - it
 * - rm
 * - en
 *
 * It is possible to alter this list by implementing this hook.
 *
 * @param array &$languages
 *    The list of languages, in order of precedence.
 *
 * @ingroup archibald_api
 */
function hook_archibald_language_fallback_list_alter(&$languages) {
  $languages[] = 'ja';
}

/**
 * Implements hook_archibald_json_export_alter().
 *
 * In order to be sent to the dsb API, description data must be encoded to
 * JSON. Archibald will load the archibald_lomch_description node and map
 * its fields to properties on the $data object. The $data object maps closely
 * to the expected JSON structure, and uses stdClasses instead of associative
 * arrays.
 *
 * @param object $data
 *    The data that will eventually get exported to JSON. Alter this data
 *    structure to update existing keys or add new data.
 * @param object $node
 *    The description node.
 *
 * @ingroup archibald_api
 */
function hook_archibald_json_export_alter(&$data, $node) {
  $data->classification[] = $new_taxonpath;
}

/**
 * @} End of "addtogroup hooks".
 */
